==> jc-1.4.0.tar.gz: java/awt/LightweightDispatcher.h <==
// class java.awt.LightweightDispatcher

// class file dependencies
// @dep_class 7fe6ff0067d79039 java_awt_LightweightDispatcher
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_LightweightDispatcher_H_
#define _JC_java_awt_LightweightDispatcher_H_

// Forward structure declarations
struct _jc_java_awt_AWTEvent$object;
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Container$object;
struct _jc_java_awt_Cursor$object;
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_LightweightDispatcher$sub_refs	_jc_java_awt_LightweightDispatcher$sub_refs;
typedef struct _jc_java_awt_LightweightDispatcher$sub_nonrefs	_jc_java_awt_LightweightDispatcher$sub_nonrefs;
typedef struct _jc_java_awt_LightweightDispatcher$refs	_jc_java_awt_LightweightDispatcher$refs;
typedef struct _jc_java_awt_LightweightDispatcher$nonrefs	_jc_java_awt_LightweightDispatcher$nonrefs;
typedef struct _jc_java_awt_LightweightDispatcher$object	_jc_java_awt_LightweightDispatcher$object;

typedef struct _jc_java_awt_LightweightDispatcher$fields_struct	_jc_java_awt_LightweightDispatcher$fields_struct;
typedef const struct _jc_java_awt_LightweightDispatcher$vmethods	_jc_java_awt_LightweightDispatcher$vmethods;
typedef const struct _jc_java_awt_LightweightDispatcher$vtable	_jc_java_awt_LightweightDispatcher$vtable;
typedef const struct _jc_java_awt_LightweightDispatcher$vtype	_jc_java_awt_LightweightDispatcher$vtype;

// Class fields structure
struct _jc_java_awt_LightweightDispatcher$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_LightweightDispatcher$fields_struct _jc_java_awt_LightweightDispatcher$class_fields;

// Constructors
extern void _jc_java_awt_LightweightDispatcher$method$_init$a6b38a8e4e977d83(_jc_env *, struct _jc_java_awt_LightweightDispatcher$object *, struct _jc_java_awt_Container$object *);

// Virtual methods
extern void _jc_java_awt_LightweightDispatcher$method$acquireComponentForMouseEvent$7263a11f36ae7acd(_jc_env *, struct _jc_java_awt_LightweightDispatcher$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern jboolean _jc_java_awt_LightweightDispatcher$method$handleEvent$46affa8d19c0137d(_jc_env *, struct _jc_java_awt_LightweightDispatcher$object *, struct _jc_java_awt_AWTEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_LightweightDispatcher$method_info$acquireComponentForMouseEvent$7263a11f36ae7acd;
extern _jc_method _jc_java_awt_LightweightDispatcher$method_info$handleEvent$46affa8d19c0137d;

// Virtual methods structure
struct _jc_java_awt_LightweightDispatcher$vmethods {
	void	(*acquireComponentForMouseEvent$7263a11f36ae7acd)(_jc_env *, struct _jc_java_awt_LightweightDispatcher$object *, struct _jc_java_awt_event_MouseEvent$object *);
	jboolean	(*handleEvent$46affa8d19c0137d)(_jc_env *, struct _jc_java_awt_LightweightDispatcher$object *, struct _jc_java_awt_AWTEvent$object *);
};

// Vtable
struct _jc_java_awt_LightweightDispatcher$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_LightweightDispatcher$vmethods	java_awt_LightweightDispatcher;
};

// Vtype
struct _jc_java_awt_LightweightDispatcher$vtype {
	_jc_type			type;
	_jc_java_awt_LightweightDispatcher$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_LightweightDispatcher$sub_refs {
	struct _jc_java_awt_Container$object	*nativeContainer;
	struct _jc_java_awt_Cursor$object	*nativeCursor;
	struct _jc_java_awt_Component$object	*mouseEventTarget;
	struct _jc_java_awt_Component$object	*pressedComponent;
	struct _jc_java_awt_Component$object	*lastComponentEntered;
};

// Reference instance fields (object)
struct _jc_java_awt_LightweightDispatcher$refs {
    _jc_java_awt_LightweightDispatcher$sub_refs	java_awt_LightweightDispatcher;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_LightweightDispatcher$sub_nonrefs {
	jlong	eventMask;
	jint	pressCount;
};

// Non-reference instance fields (object)
struct _jc_java_awt_LightweightDispatcher$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_LightweightDispatcher$sub_nonrefs	java_awt_LightweightDispatcher;
};

// Object instance structure
struct _jc_java_awt_LightweightDispatcher$object {
	_jc_java_awt_LightweightDispatcher$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_LightweightDispatcher$vtype	*vtype;
	_jc_java_awt_LightweightDispatcher$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_LightweightDispatcher$vtype _jc_java_awt_LightweightDispatcher$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_LightweightDispatcher, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_LightweightDispatcher$class_object;

#endif	/* _JC_java_awt_LightweightDispatcher_H_ */

==> jc-1.4.5.tar.gz: java/awt/LightweightDispatcher.h <==
// class java.awt.LightweightDispatcher

// class file dependencies
// @dep_class 7fe6ff0067d79039 java_awt_LightweightDispatcher
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_LightweightDispatcher_H_
#define _JC_java_awt_LightweightDispatcher_H_

// Forward structure declarations
struct _jc_java_awt_AWTEvent$object;
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Container$object;
struct _jc_java_awt_Cursor$object;
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_LightweightDispatcher$sub_refs	_jc_java_awt_LightweightDispatcher$sub_refs;
typedef struct _jc_java_awt_LightweightDispatcher$sub_nonrefs	_jc_java_awt_LightweightDispatcher$sub_nonrefs;
typedef struct _jc_java_awt_LightweightDispatcher$refs	_jc_java_awt_LightweightDispatcher$refs;
typedef struct _jc_java_awt_LightweightDispatcher$nonrefs	_jc_java_awt_LightweightDispatcher$nonrefs;
typedef struct _jc_java_awt_LightweightDispatcher$object	_jc_java_awt_LightweightDispatcher$object;

typedef struct _jc_java_awt_LightweightDispatcher$fields_struct	_jc_java_awt_LightweightDispatcher$fields_struct;
typedef const struct _jc_java_awt_LightweightDispatcher$vmethods	_jc_java_awt_LightweightDispatcher$vmethods;
typedef const struct _jc_java_awt_LightweightDispatcher$vtable	_jc_java_awt_LightweightDispatcher$vtable;
typedef const struct _jc_java_awt_LightweightDispatcher$vtype	_jc_java_awt_LightweightDispatcher$vtype;

// Class fields structure
struct _jc_java_awt_LightweightDispatcher$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_LightweightDispatcher$fields_struct _jc_java_awt_LightweightDispatcher$class_fields;

// Constructors
extern void _jc_java_awt_LightweightDispatcher$method$_init$a6b38a8e4e977d83(_jc_env *, struct _jc_java_awt_LightweightDispatcher$object *, struct _jc_java_awt_Container$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_LightweightDispatcher$method$acquireComponentForMouseEvent$7263a11f36ae7acd(_jc_env *, struct _jc_java_awt_LightweightDispatcher$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_LightweightDispatcher$method$handleEvent$46affa8d19c0137d(_jc_env *, struct _jc_java_awt_LightweightDispatcher$object *, struct _jc_java_awt_AWTEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_LightweightDispatcher$method_info$acquireComponentForMouseEvent$7263a11f36ae7acd;
extern _jc_method _jc_java_awt_LightweightDispatcher$method_info$handleEvent$46affa8d19c0137d;

// Virtual methods structure
struct _jc_java_awt_LightweightDispatcher$vmethods {
	void	(*acquireComponentForMouseEvent$7263a11f36ae7acd)(_jc_env *, struct _jc_java_awt_LightweightDispatcher$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	jboolean	(*handleEvent$46affa8d19c0137d)(_jc_env *, struct _jc_java_awt_LightweightDispatcher$object *, struct _jc_java_awt_AWTEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_LightweightDispatcher$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_LightweightDispatcher$vmethods	java_awt_LightweightDispatcher;
};

// Vtype
struct _jc_java_awt_LightweightDispatcher$vtype {
	_jc_type			type;
	_jc_java_awt_LightweightDispatcher$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_LightweightDispatcher$sub_refs {
	struct _jc_java_awt_Container$object	*nativeContainer;
	struct _jc_java_awt_Cursor$object	*nativeCursor;
	struct _jc_java_awt_Component$object	*mouseEventTarget;
	struct _jc_java_awt_Component$object	*pressedComponent;
	struct _jc_java_awt_Component$object	*lastComponentEntered;
};

// Reference instance fields (object)
struct _jc_java_awt_LightweightDispatcher$refs {
    _jc_java_awt_LightweightDispatcher$sub_refs	java_awt_LightweightDispatcher;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_LightweightDispatcher$sub_nonrefs {
	jlong	eventMask;
	jint	pressCount;
};

// Non-reference instance fields (object)
struct _jc_java_awt_LightweightDispatcher$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_LightweightDispatcher$sub_nonrefs	java_awt_LightweightDispatcher;
};

// Object instance structure
struct _jc_java_awt_LightweightDispatcher$object {
	_jc_java_awt_LightweightDispatcher$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_LightweightDispatcher$vtype	*vtype;
	_jc_java_awt_LightweightDispatcher$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_LightweightDispatcher$vtype _jc_java_awt_LightweightDispatcher$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_LightweightDispatcher, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_LightweightDispatcher$class_object;

#endif	/* _JC_java_awt_LightweightDispatcher_H_ */
